@@ -1,13 +1,13 @@
-# Copyrights 2003,2007 by Mark Overmeer.
+# Copyrights 2003,2007-2008 by Mark Overmeer.
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.02.
+# Pod stripped from pm file by OODoc 1.03.
 use strict;
 use warnings;
 
 package OODoc::Template;
 use vars '$VERSION';
-$VERSION = '0.12';
+$VERSION = '0.13';
 
 use IO::File   ();
 use Data::Dumper;
@@ -50,7 +50,8 @@ sub process($)
     defined $tree
         or return ();
 
-    $self->pushValues($values) if keys %$values;
+    $self->pushValues($values)
+        if keys %$values;
 
     my @output;
     foreach my $node (@$tree)
@@ -161,7 +162,7 @@ sub processFile($;@)
 
 sub defineMacro($$$$)
 {   my ($self, $tag, $attrs, $then, $else) = @_;
-    my $name = $attrs->{name}
+    my $name = delete $attrs->{name}
         or die "ERROR: macro requires a name\n";
 
     defined $else
